@@ -45,6 +45,7 @@ DATA_ATTRIBUTES_KEYS = [
     "stepUnits",
     "stepType",
     "gridType",
+    "uvRelativeToGrid"
 ]
 
 EXTRA_DATA_ATTRIBUTES_KEYS = [
@@ -160,6 +161,7 @@ ALL_REF_TIME_KEYS = [
     "verifying_time",
     "forecastMonth",
     "indexing_time",
+    "valid_month",
 ]
 SPECTRA_KEYS = ["directionNumber", "frequencyNumber"]
 
@@ -250,6 +252,12 @@ COORD_ATTRS = {
         "standard_name": "time",
         "long_name": "time",
     },
+    "valid_month": {
+        "units": "seconds since 1970-01-01T00:00:00",
+        "calendar": "proleptic_gregorian",
+        "standard_name": "time",
+        "long_name": "time",
+    },
     "verifying_time": {
         "units": "seconds since 1970-01-01T00:00:00",
         "calendar": "proleptic_gregorian",
@@ -457,10 +465,7 @@ def encode_cf_first(data_var_attrs, encode_cf=("parameter", "time"), time_dims=(
         if "GRIB_units" in data_var_attrs:
             data_var_attrs["units"] = data_var_attrs["GRIB_units"]
     if "time" in encode_cf:
-        if set(time_dims).issubset(ALL_REF_TIME_KEYS):
-            coords_map.extend(time_dims)
-        else:
-            raise ValueError("time_dims %r not a subset of %r" % (time_dims, ALL_REF_TIME_KEYS))
+        coords_map.extend(time_dims)
     else:
         coords_map.extend(DATA_TIME_KEYS)
     coords_map.extend(VERTICAL_KEYS)
@@ -490,6 +495,7 @@ def build_variable_components(
     read_keys: T.Iterable[str] = (),
     time_dims: T.Sequence[str] = ("time", "step"),
     extra_coords: T.Dict[str, str] = {},
+    coords_as_attributes: T.Dict[str, str] = {},
     cache_geo_coords: bool = True,
 ) -> T.Tuple[T.Dict[str, int], Variable, T.Dict[str, Variable]]:
     data_var_attrs = enforce_unique_attributes(index, DATA_ATTRIBUTES_KEYS, filter_by_keys)
@@ -498,8 +504,9 @@ def build_variable_components(
     first = index.first()
     extra_attrs = read_data_var_attrs(first, extra_keys)
     data_var_attrs.update(**extra_attrs)
-    coords_map = encode_cf_first(data_var_attrs, encode_cf, time_dims)
-
+    coords_map = encode_cf_first(
+        data_var_attrs, encode_cf, time_dims,
+    )
     coord_name_key_map = {}
     coord_vars = {}
     for coord_key in coords_map:
@@ -515,6 +522,9 @@ def build_variable_components(
             and "GRIB_typeOfLevel" in data_var_attrs
         ):
             coord_name = data_var_attrs["GRIB_typeOfLevel"]
+        if coord_name in coords_as_attributes and len(values) == 1:
+            data_var_attrs[f"GRIB_{coord_name}"] = values
+            continue
         coord_name_key_map[coord_name] = coord_key
         attributes = {
             "long_name": "original GRIB coordinate for key: %s(%s)" % (orig_name, coord_name),
@@ -661,12 +671,21 @@ def build_dataset_components(
     read_keys: T.Iterable[str] = (),
     time_dims: T.Sequence[str] = ("time", "step"),
     extra_coords: T.Dict[str, str] = {},
+    coords_as_attributes: T.Dict[str, str] = {},
     cache_geo_coords: bool = True,
 ) -> T.Tuple[T.Dict[str, int], T.Dict[str, Variable], T.Dict[str, T.Any], T.Dict[str, T.Any]]:
     dimensions = {}  # type: T.Dict[str, int]
     variables = {}  # type: T.Dict[str, Variable]
     filter_by_keys = index.filter_by_keys
 
+    # Warn about time_dims here to prevent repeasted messages in build_variable_components
+    if errors != "ignore" and not set(time_dims).issubset(ALL_REF_TIME_KEYS):
+        log.warning(
+            "Not all time_dimensions are recognised, those which are not in the following list will not "
+            " be decoded as datetime objects:\n"
+            f"{ALL_REF_TIME_KEYS}"
+        )
+    
     for param_id in index.get("paramId", []):
         var_index = index.subindex(paramId=param_id)
         try:
@@ -679,6 +698,7 @@ def build_dataset_components(
                 read_keys=read_keys,
                 time_dims=time_dims,
                 extra_coords=extra_coords,
+                coords_as_attributes=coords_as_attributes,
                 cache_geo_coords=cache_geo_coords,
             )
         except DatasetBuildError as ex:
@@ -801,5 +821,4 @@ def open_file(
     stream = messages.FileStream(path, errors=errors)
     index_keys = compute_index_keys(time_dims, extra_coords)
     index = open_fileindex(stream, indexpath, index_keys, ignore_keys=ignore_keys, filter_by_keys=filter_by_keys)
-
     return open_from_index(index, read_keys, time_dims, extra_coords, errors=errors, **kwargs)
